@@ -7,6 +7,7 @@ import (
 	"log"
 	"os"
 	"sync"
+	"time"
 
 	"github.com/hashicorp/go-multierror"
 	"github.com/hashicorp/hcp-sdk-go/clients/cloud-packer-service/stable/2021-04-30/models"
@@ -15,6 +16,10 @@ import (
 	"google.golang.org/grpc/codes"
 )
 
+// HeartbeatPeriod dictates how often a heartbeat is sent to HCP to signal a
+// build is still alive.
+const HeartbeatPeriod = 2 * time.Minute
+
 // Bucket represents a single Image bucket on the HCP Packer registry.
 type Bucket struct {
 	Slug                           string
@@ -22,18 +27,23 @@ type Bucket struct {
 	Destination                    string
 	BucketLabels                   map[string]string
 	BuildLabels                    map[string]string
-	SourceImagesToParentIterations map[string]string
+	SourceImagesToParentIterations map[string]ParentIteration
 	Iteration                      *Iteration
 	client                         *Client
 }
 
+type ParentIteration struct {
+	IterationID string
+	ChannelID   string
+}
+
 // NewBucketWithIteration initializes a simple Bucket that can be used publishing Packer build
 // images to the HCP Packer registry.
 func NewBucketWithIteration(opts IterationOptions) (*Bucket, error) {
 	b := Bucket{
 		BucketLabels:                   make(map[string]string),
 		BuildLabels:                    make(map[string]string),
-		SourceImagesToParentIterations: make(map[string]string),
+		SourceImagesToParentIterations: make(map[string]ParentIteration),
 	}
 
 	i, err := NewIteration(opts)
@@ -139,9 +149,10 @@ func (b *Bucket) CreateInitialBuildForIteration(ctx context.Context, componentTy
 }
 
 // UpdateBuildStatus updates the status of a build entry on the HCP Packer registry with its current local status.
+// For updating a build status to DONE use CompleteBuild.
 func (b *Bucket) UpdateBuildStatus(ctx context.Context, name string, status models.HashicorpCloudPackerBuildStatus) error {
 	if status == models.HashicorpCloudPackerBuildStatusDONE {
-		return b.markBuildComplete(ctx, name)
+		return fmt.Errorf("do not use UpdateBuildStatus for updating to DONE")
 	}
 
 	buildToUpdate, err := b.Iteration.Build(name)
@@ -153,13 +164,18 @@ func (b *Bucket) UpdateBuildStatus(ctx context.Context, name string, status mode
 		return fmt.Errorf("the build for the component %q does not have a valid id", name)
 	}
 
+	if buildToUpdate.Status == models.HashicorpCloudPackerBuildStatusDONE {
+		return fmt.Errorf("cannot modify status of DONE build %s", name)
+	}
+
 	_, err = b.client.UpdateBuild(ctx,
 		buildToUpdate.ID,
 		buildToUpdate.RunUUID,
-		buildToUpdate.CloudProvider,
 		"",
 		"",
-		buildToUpdate.Labels,
+		"",
+		"",
+		nil,
 		status,
 		nil,
 	)
@@ -171,10 +187,10 @@ func (b *Bucket) UpdateBuildStatus(ctx context.Context, name string, status mode
 	return nil
 }
 
-// markBuildComplete should be called to set a build on the HCP Packer registry to DONE.
+// CompleteBuild should be called to set a build on the HCP Packer registry to DONE.
 // Upon a successful call markBuildComplete will publish all images created by the named build,
 // and set the registry build to done. A build with no images can not be set to DONE.
-func (b *Bucket) markBuildComplete(ctx context.Context, name string) error {
+func (b *Bucket) CompleteBuild(ctx context.Context, name string) error {
 	buildToUpdate, err := b.Iteration.Build(name)
 	if err != nil {
 		return err
@@ -195,7 +211,7 @@ func (b *Bucket) markBuildComplete(ctx context.Context, name string) error {
 		return fmt.Errorf("setting a build to DONE with no published images is not currently supported.")
 	}
 
-	var providerName, sourceID, sourceIterationID string
+	var providerName, sourceID, sourceIterationID, sourceChannelID string
 	images := make([]*models.HashicorpCloudPackerImageCreateBody, 0, len(buildToUpdate.Images))
 	for _, image := range buildToUpdate.Images {
 		// These values will always be the same for all images in a single build,
@@ -209,7 +225,8 @@ func (b *Bucket) markBuildComplete(ctx context.Context, name string) error {
 
 		// Check if image is using some other HCP Packer image
 		if v, ok := b.SourceImagesToParentIterations[image.SourceImageID]; ok {
-			sourceIterationID = v
+			sourceIterationID = v.IterationID
+			sourceChannelID = v.ChannelID
 		}
 
 		images = append(images, &models.HashicorpCloudPackerImageCreateBody{ImageID: image.ImageID, Region: image.ProviderRegion})
@@ -221,6 +238,7 @@ func (b *Bucket) markBuildComplete(ctx context.Context, name string) error {
 		buildToUpdate.CloudProvider,
 		sourceID,
 		sourceIterationID,
+		sourceChannelID,
 		buildToUpdate.Labels,
 		status,
 		images,
@@ -402,3 +420,57 @@ func (b *Bucket) IsExpectingBuildForComponent(buildName string) bool {
 
 	return build.IsNotDone()
 }
+
+// HeartbeatBuild periodically sends status updates for the build
+//
+// This lets HCP infer that a build is still running and should not be marked
+// as cancelled by the HCP Packer registry service.
+//
+// Usage: defer (b.HeartbeatBuild(ctx, build, period))()
+func (b *Bucket) HeartbeatBuild(ctx context.Context, build string) (func(), error) {
+	buildToUpdate, err := b.Iteration.Build(build)
+	if err != nil {
+		return nil, err
+	}
+
+	heartbeatChan := make(chan struct{})
+	go func() {
+		log.Printf("[TRACE] starting heartbeats")
+
+		tick := time.NewTicker(HeartbeatPeriod)
+
+	outHeartbeats:
+		for {
+			select {
+			case <-heartbeatChan:
+				tick.Stop()
+				break outHeartbeats
+			case <-ctx.Done():
+				tick.Stop()
+				break outHeartbeats
+			case <-tick.C:
+				_, err = b.client.UpdateBuild(ctx,
+					buildToUpdate.ID,
+					buildToUpdate.RunUUID,
+					"",
+					"",
+					"",
+					"",
+					nil,
+					models.HashicorpCloudPackerBuildStatusRUNNING,
+					nil,
+				)
+				if err != nil {
+					log.Printf("[ERROR] failed to send heartbeat for build %q: %s", build, err)
+				} else {
+					log.Printf("[TRACE] updating build status for %q to running", build)
+				}
+			}
+		}
+
+		log.Printf("[TRACE] stopped heartbeating build %s", build)
+	}()
+	return func() {
+		close(heartbeatChan)
+	}, nil
+}
