@@ -14,7 +14,7 @@ declare -a plugins=(
 	"hashicorp/packer-plugin-chef"
 	"hashicorp/packer-plugin-cloudstack"
 	"hashicorp/packer-plugin-converge"
-	"hashicorp/packer-plugin-digitalocean"
+	"digitalocean/packer-plugin-digitalocean"
 	"hashicorp/packer-plugin-docker"
 	"hashicorp/packer-plugin-googlecompute"
 	"hashicorp/packer-plugin-hcloud"
@@ -27,14 +27,12 @@ declare -a plugins=(
 	"hashicorp/packer-plugin-ncloud"
 	"hashicorp/packer-plugin-openstack"
 	"hashicorp/packer-plugin-oracle"
-	"outscale/packer-plugin-outscale"
 	"hashicorp/packer-plugin-oneandone"
 	"hashicorp/packer-plugin-parallels"
 	"hashicorp/packer-plugin-profitbricks"
 	"hashicorp/packer-plugin-proxmox"
 	"hashicorp/packer-plugin-puppet"
 	"hashicorp/packer-plugin-qemu"
-	"scaleway/packer-plugin-scaleway"
 	"hashicorp/packer-plugin-sdk"
 	"hashicorp/packer-plugin-tencentcloud"
 	"hashicorp/packer-plugin-triton"
